Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/DocumentIndex.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/DocumentIndex.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/text/DocumentIndex.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/text/DocumentIndex.idl 
Tue Jun 11 12:06:28 2019
@@ -42,35 +42,35 @@ published service DocumentIndex
 {
        service  com::sun::star::text::BaseIndex;
 
-       /** determins if alphabetical separators are genererated.
+       /** determines if alphabetical separators are genererated.
         */
        [optional, property] boolean UseAlphabeticalSeparators;
 
-       /** determins if a index entry is generated for each primary/secondary 
key.
+       /** determines if a index entry is generated for each primary/secondary 
key.
         */
        [optional, property] boolean UseKeyAsEntry;
 
-       /** determins if same entries on different pages are combined into one 
index entry.
+       /** determines if same entries on different pages are combined into one 
index entry.
         */
        [optional, property] boolean UseCombinedEntries;
 
-       /** determins if the similarity of index entries is checked case 
sensitively.
+       /** determines if the similarity of index entries is checked case 
sensitively.
         */
        [optional, property] boolean IsCaseSensitive;
 
-       /** determins if following page numbers are displayed using a 'pp.'.
+       /** determines if following page numbers are displayed using a 'pp.'.
         */
        [optional, property] boolean UsePP;
 
-       /** determins if if following page numbers are displayed using a dash.
+       /** determines if if following page numbers are displayed using a dash.
         */
        [optional, property] boolean UseDash;
 
-       /** determins if all entries start with a capital letter.
+       /** determines if all entries start with a capital letter.
         */
        [optional, property] boolean UseUpperCase;
 
-       /** determins the name of the character style that is applied to the 
number
+       /** determines the name of the character style that is applied to the 
number
         of a page where main index entry is located.
         */
        [optional, property] string MainEntryCharacterStyleName;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/DocumentIndexMark.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/DocumentIndexMark.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/DocumentIndexMark.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/DocumentIndexMark.idl 
Tue Jun 11 12:06:28 2019
@@ -57,7 +57,7 @@ published service DocumentIndexMark
         */
        [property] string SecondaryKey;
        
//-------------------------------------------------------------------------
-       /** determins if this entry is a main entry. In a document index this 
entry will
+       /** determines if this entry is a main entry. In a document index this 
entry will
                be emphasized by assigning a character style to it.
         */
        [property] boolean IsMainEntry;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/FontEmphasis.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/FontEmphasis.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/text/FontEmphasis.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/text/FontEmphasis.idl 
Tue Jun 11 12:06:28 2019
@@ -29,7 +29,7 @@
  module com {  module sun {  module star {  module text {
 
 //=============================================================================
-/**  Determins the type and position of an emphasis mark in asian texts.
+/**  Determines the type and position of an emphasis mark in asian texts.
  */
 published constants FontEmphasis
 {

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/FontRelief.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/FontRelief.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/text/FontRelief.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/text/FontRelief.idl Tue 
Jun 11 12:06:28 2019
@@ -29,7 +29,7 @@
  module com {  module sun {  module star {  module text {
 
 //=============================================================================
-/**  Determins the relief type of a font.
+/**  Determines the relief type of a font.
  */
 published constants FontRelief
 {

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/NumberingRules.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/NumberingRules.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/text/NumberingRules.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/text/NumberingRules.idl 
Tue Jun 11 12:06:28 2019
@@ -56,19 +56,19 @@ published service NumberingRules
        [optional] interface com::sun::star::beans::XPropertySet;
        
//-------------------------------------------------------------------------
 
-       /** determins if the margins are absolute or relative
+       /** determines if the margins are absolute or relative
                to the preceding numbering level.
         */
        [optional, property] boolean  IsAbsoluteMargins;
        
//-------------------------------------------------------------------------
 
-       /** determins if the numbering rules are automatically created
+       /** determines if the numbering rules are automatically created
                as opposed to numbering rules that are part of a numbering 
style.
         */
        [optional, property] boolean IsAutomatic;
        
//-------------------------------------------------------------------------
 
-       /** determins if the numbering levels are counted coninuously  or if
+       /** determines if the numbering levels are counted coninuously  or if
         each numbering level is counted separately.
         */
        [optional, property] boolean IsContinuousNumbering;

Modified: openoffice/branches/AOO42X/main/offapi/com/sun/star/text/SizeType.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/SizeType.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/text/SizeType.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/text/SizeType.idl Tue 
Jun 11 12:06:28 2019
@@ -48,7 +48,7 @@ published constants SizeType
        const short VARIABLE = 0; 
  
        
//------------------------------------------------------------------------- 
-       // The height property determins the height of the object. 
+       // The height property determines the height of the object. 
        
        // DocMerge: empty anyway
        const short FIX = 1; 

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextFieldMaster.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextFieldMaster.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextFieldMaster.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextFieldMaster.idl 
Tue Jun 11 12:06:28 2019
@@ -46,7 +46,7 @@ published service TextFieldMaster
         */
        [optional] interface com::sun::star::beans::XPropertySet;
     //------------------------------------------------------------------------
-    /** determins the name of the field master. The name is void as long as the
+    /** determines the name of the field master. The name is void as long as 
the
      instance is not member of the document structure. When the value is being 
set
      the instance is inserted into the document and the name cannot be changed 
afterwards.
      That does not apply to the Database text field master.

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextGraphicObject.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextGraphicObject.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextGraphicObject.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextGraphicObject.idl 
Tue Jun 11 12:06:28 2019
@@ -144,11 +144,11 @@ published service TextGraphicObject
         */
        [property] short AdjustBlue;
        
//-------------------------------------------------------------------------
-       /** determins the gamma value of the graphic.
+       /** determines the gamma value of the graphic.
         */
        [property] double Gamma;
        
//-------------------------------------------------------------------------
-       /** determins if the graphic is display in inverted colors.
+       /** determines if the graphic is display in inverted colors.
                It contains percentage values between -100 and +100.
         */
        [property] boolean GraphicIsInverted;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextPageStyle.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextPageStyle.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextPageStyle.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextPageStyle.idl 
Tue Jun 11 12:06:28 2019
@@ -69,7 +69,7 @@ published service TextPageStyle
 {
        
//-------------------------------------------------------------------------
 
-       /** determins whether the register mode is active on that page.
+       /** determines whether the register mode is active on that page.
         */
        [property] boolean RegisterModeActive;
 

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextSection.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextSection.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextSection.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextSection.idl 
Tue Jun 11 12:06:28 2019
@@ -154,90 +154,90 @@ published service TextSection
                @see GraphicLocation
        */
        [property] com::sun::star::style::GraphicLocation BackGraphicLocation;
-       /** determins whether footnotes inside the section are displayed at the 
end of the
+       /** determines whether footnotes inside the section are displayed at 
the end of the
         section text.
        */
        [property] boolean FootnoteIsCollectAtTextEnd;
        
//-------------------------------------------------------------------------
-       /** determins whether the footnotes numbering restarts within the 
section.
+       /** determines whether the footnotes numbering restarts within the 
section.
         This is only valid if <code>FootnoteIsRestartNumbering</code> is set.
        */
        [property] boolean FootnoteIsRestartNumbering;
        
//-------------------------------------------------------------------------
-       /** determins at which number the footnote numbering inside of the 
section starts.
+       /** determines at which number the footnote numbering inside of the 
section starts.
         This is only valid if <code>FootnoteIsRestartNumbering</code> is set.
        */
        [property] short FootnoteRestartNumberingAt;
        
//-------------------------------------------------------------------------
-       /** determins whether the footnotes within the section use an own 
numbering format.
+       /** determines whether the footnotes within the section use an own 
numbering format.
         This is only valid if <code>FootnoteIsRestartNumbering</code> is set.
        */
        [property] boolean FootnoteIsOwnNumbering;
        
//-------------------------------------------------------------------------
-       /** determins the numbering type of the footnote numbering as a value of
+       /** determines the numbering type of the footnote numbering as a value 
of
         <type scope="com::sun::star::style">NumberingType</type>.
         This is only valid if <code>FootnoteIsOwnNumbering</code> is set.
        */
        [property] short FootnoteNumberingType;
        
//-------------------------------------------------------------------------
-       /** determins the prefix that is display before the footnote number.
+       /** determines the prefix that is display before the footnote number.
         This is only valid if <code>FootnoteIsOwnNumbering</code> is set.
        */
        [property] string FootnoteNumberingPrefix;
        
//-------------------------------------------------------------------------
-       /** determins the suffix that is display after of the footnote number.
+       /** determines the suffix that is display after of the footnote number.
         This is only valid if <code>FootnoteIsOwnNumbering</code> is set.
        */
        [property] string FootnoteNumberingSuffix;
        
//-------------------------------------------------------------------------
-       /** determins whether endnotes inside the section are displayed at the 
end of the
+       /** determines whether endnotes inside the section are displayed at the 
end of the
         section text.
        */
        [property] boolean EndnoteIsCollectAtTextEnd;
        
//-------------------------------------------------------------------------
-       /** determins whether the endnotes numbering restarts within the 
section.
+       /** determines whether the endnotes numbering restarts within the 
section.
         This is only valid if <code>EndnoteIsRestartNumbering</code> is set.
        */
        [property] boolean EndnoteIsRestartNumbering;
        
//-------------------------------------------------------------------------
-       /** determins at which number the endnote numbering inside of the 
section starts.
+       /** determines at which number the endnote numbering inside of the 
section starts.
         This is only valid if <code>EndnoteIsRestartNumbering</code> is set.
        */
        [property] short EndnoteRestartNumberingAt;
        
//-------------------------------------------------------------------------
-       /** determins whether the endnotes within the section use an own 
numbering format.
+       /** determines whether the endnotes within the section use an own 
numbering format.
         This is only valid if <code>EndnoteIsRestartNumbering</code> is set.
        */
        [property] boolean EndnoteIsOwnNumbering;
        
//-------------------------------------------------------------------------
-       /** determins the numbering type of the endnote numbering as a value of
+       /** determines the numbering type of the endnote numbering as a value of
         <type scope="com::sun::star::style">NumberingType</type>.
         This is only valid if <code>EndoteIsOwnNumbering</code> is set.
        */
        [property] short EndnoteNumberingType;
        
//-------------------------------------------------------------------------
-       /** determins the prefix that is display before the endnote number.
+       /** determines the prefix that is display before the endnote number.
         This is only valid if <code>EndnoteIsOwnNumbering</code> is set.
        */
        [property] string EndnoteNumberingPrefix;
        
//-------------------------------------------------------------------------
-       /** determins the suffix that is display after the endnote number.
+       /** determines the suffix that is display after the endnote number.
         This is only valid if <code>EndnoteIsOwnNumbering</code> is set.
        */
        [property] string EndnoteNumberingSuffix;
        
//-------------------------------------------------------------------------
-       /** determins if a DDE link is updated automatically.
+       /** determines if a DDE link is updated automatically.
        */
        [property] boolean IsAutomaticUpdate;
        
//-------------------------------------------------------------------------
        /** allows columns to be set into the text section
        */
        [property] com::sun::star::text::XTextColumns TextColumns;
-    /** determins the left margin of the section
+    /** determines the left margin of the section
      */
     [optional, property] long SectionLeftMargin;
        
//-------------------------------------------------------------------------
-    /** determins the left margin of the section
+    /** determines the left margin of the section
      */
     [optional, property] long SectionRightMargin;
        
//-------------------------------------------------------------------------

Modified: openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextTable.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextTable.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextTable.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/text/TextTable.idl Tue 
Jun 11 12:06:28 2019
@@ -135,7 +135,7 @@ published service TextTable
 
     [optional] interface com::sun::star::sheet::XCellRangeData;
 
-       /** determins the type of break that is applied at the beginning of the 
table. @see com::sun::star::style::BreakType
+       /** determines the type of break that is applied at the beginning of 
the table. @see com::sun::star::style::BreakType
         */
        [property] com::sun::star::style::BreakType BreakType;
        
//-------------------------------------------------------------------------
@@ -179,40 +179,40 @@ published service TextTable
        [property] string PageDescName;
        
//-------------------------------------------------------------------------
 
-       /** determins the width of the table relative to its environment.
+       /** determines the width of the table relative to its environment.
         */
        [property] short RelativeWidth;
        
//-------------------------------------------------------------------------
-       /** determins if the value of the relative width is valid.
+       /** determines if the value of the relative width is valid.
         */
     [property] boolean IsWidthRelative;
        
//-------------------------------------------------------------------------
 
-       /** determins if the first row of the table is repeated on every new 
page.
+       /** determines if the first row of the table is repeated on every new 
page.
         */
        [property] boolean RepeatHeadline;
         
//-------------------------------------------------------------------------
-        /** determins the number of rows of the table repeated on every new 
page.
+        /** determines the number of rows of the table repeated on every new 
page.
          */
         [optional, property] long HeaderRowCount;
         
//-------------------------------------------------------------------------
 
-       /** determins the type, color and size of the shadow. @see 
com::sun::star::table::ShadowFormat
+       /** determines the type, color and size of the shadow. @see 
com::sun::star::table::ShadowFormat
         */
        [property] com::sun::star::table::ShadowFormat ShadowFormat;
        
//-------------------------------------------------------------------------
 
-       /** determins the top margin.
+       /** determines the top margin.
         */
        [property] long TopMargin;
        
//-------------------------------------------------------------------------
 
-       /** determins the bottom margin.
+       /** determines the bottom margin.
         */
        [property] long BottomMargin;
        
//-------------------------------------------------------------------------
 
-       /** determins if the background color is transparent.
+       /** determines if the background color is transparent.
         */
        [property] boolean BackTransparent;
        
//-------------------------------------------------------------------------
@@ -226,13 +226,13 @@ published service TextTable
        [property] long Width;
        
//-------------------------------------------------------------------------
 
-       /** determins if the first row of the table should be treated as
+       /** determines if the first row of the table should be treated as
                axis labels when a chart is to be created.
         */
        [property] boolean ChartRowAsLabel;
        
//-------------------------------------------------------------------------
 
-       /** determins if the first column of the table should be treated as
+       /** determines if the first column of the table should be treated as
                axis labels when a chart is to be created.
         */
        [property] boolean ChartColumnAsLabel;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/UserDefinedIndex.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/UserDefinedIndex.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/UserDefinedIndex.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/UserDefinedIndex.idl 
Tue Jun 11 12:06:28 2019
@@ -48,27 +48,27 @@ published service UserDefinedIndex
         */
        [optional, property] com::sun::star::container::XIndexReplace 
LevelParagraphStyles;
 
-       /** determins if the document index marks are included in this index.
+       /** determines if the document index marks are included in this index.
         */
        [optional, property] boolean CreateFromMarks;
 
-       /** determins if the outline level of the location of the indexed 
object is
+       /** determines if the outline level of the location of the indexed 
object is
         used as index level of the index entry.*/
        [optional, property] boolean UseLevelFromSource;
 
-       /** determins if tables are included in the index.
+       /** determines if tables are included in the index.
         */
        [optional, property] boolean CreateFromTables;
 
-       /** determins if text frames are included in the index.
+       /** determines if text frames are included in the index.
         */
        [optional, property] boolean CreateFromTextFrames;
 
-       /** determins if graphic objects are included in the index.
+       /** determines if graphic objects are included in the index.
         */
        [optional, property] boolean CreateFromGraphicObjects;
 
-       /** determins if embedded objects are included in the index.
+       /** determines if embedded objects are included in the index.
         */
        [optional, property] boolean CreateFromEmbeddedObjects;
 

Modified: openoffice/branches/AOO42X/main/offapi/com/sun/star/text/UserIndex.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/UserIndex.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/text/UserIndex.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/text/UserIndex.idl Tue 
Jun 11 12:06:28 2019
@@ -44,27 +44,27 @@ published service UserIndex
         */
        [optional, property] com::sun::star::container::XIndexReplace 
LevelParagraphStyles;
 
-       /** determins if the document index marks are included in this index.
+       /** determines if the document index marks are included in this index.
         */
        [optional, property] boolean CreateFromMarks;
 
-       /** determins if the outline level of the location of the indexed 
object is
+       /** determines if the outline level of the location of the indexed 
object is
         used as index level of the index entry.*/
        [optional, property] boolean UseLevelFromSource;
 
-       /** determins if tables are included in the index.
+       /** determines if tables are included in the index.
         */
        [optional, property] boolean CreateFromTables;
 
-       /** determins if text frames are included in the index.
+       /** determines if text frames are included in the index.
         */
        [optional, property] boolean CreateFromTextFrames;
 
-       /** determins if graphic objects are included in the index.
+       /** determines if graphic objects are included in the index.
         */
        [optional, property] boolean CreateFromGraphicObjects;
 
-       /** determins if embedded objects are included in the index.
+       /** determines if embedded objects are included in the index.
         */
        [optional, property] boolean CreateFromEmbeddedObjects;
     /** contains the name of the user index.

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XNumberingTypeInfo.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XNumberingTypeInfo.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XNumberingTypeInfo.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XNumberingTypeInfo.idl 
Tue Jun 11 12:06:28 2019
@@ -46,7 +46,7 @@ published interface XNumberingTypeInfo :
        /** returns the corresponding numbering type to an identifier.
        */
        short   getNumberingType([in]string NumberingIdentifier);
-       /** determins whether an identifier is supported.
+       /** determines whether an identifier is supported.
        */
        boolean hasNumberingType([in]string NumberingIdentifier);
        /** returns the corresponding identifiert to a numbering type.

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XPagePrintable.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XPagePrintable.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XPagePrintable.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XPagePrintable.idl 
Tue Jun 11 12:06:28 2019
@@ -60,7 +60,7 @@ published interface XPagePrintable: com:
                                <LI><P>long BottomMargin - bottom margin of the 
page</P>
                                <LI><P>long HoriMargin  - margin between rows 
of pages</P>
                                <LI><P>long VertMargin  - margin between 
columns of pages</P>
-                               <LI><P>boolean IsLandscape - determins if the 
output page is printed in landscape format</P>
+                               <LI><P>boolean IsLandscape - determines if the 
output page is printed in landscape format</P>
                        </UL>
                         </p>
         */

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XTextTableCursor.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XTextTableCursor.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XTextTableCursor.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/XTextTableCursor.idl 
Tue Jun 11 12:06:28 2019
@@ -63,7 +63,7 @@ published interface XTextTableCursor: co
                        specifies the name of the cell to go to.
 
                @param bExpand
-                       determines wether the selection is to be expanded.
+                       determines whether the selection is to be expanded.
 
         @see com::sun::star::text::Cell
         */
@@ -78,7 +78,7 @@ published interface XTextTableCursor: co
                        the number of cells to move.
 
                @param bExpand
-                       determines wether the selection is to be expanded.
+                       determines whether the selection is to be expanded.
         */
        boolean goLeft( [in] short nCount,
                         [in] boolean bExpand );
@@ -91,7 +91,7 @@ published interface XTextTableCursor: co
                        the number of cells to move.
 
                @param bExpand
-                       determines wether the selection is to be expanded.
+                       determines whether the selection is to be expanded.
         */
        boolean goRight( [in] short nCount,
                         [in] boolean bExpand );
@@ -104,7 +104,7 @@ published interface XTextTableCursor: co
                        the number of cells to move.
 
                @param bExpand
-                       determines wether the selection is to be expanded.
+                       determines whether the selection is to be expanded.
         */
        boolean goUp( [in] short nCount,
                         [in] boolean bExpand );
@@ -117,7 +117,7 @@ published interface XTextTableCursor: co
                        the number of cells to move.
 
                @param bExpand
-                       determines wether the selection is to be expanded.
+                       determines whether the selection is to be expanded.
         */
        boolean goDown( [in] short nCount,
                         [in] boolean bExpand );
@@ -127,7 +127,7 @@ published interface XTextTableCursor: co
        /** moves the cursor to the top left cell of the table.
 
                @param bExpand
-                       determines wether the selection is to be expanded.
+                       determines whether the selection is to be expanded.
         */
        void gotoStart( [in] boolean bExpand );
 
@@ -136,7 +136,7 @@ published interface XTextTableCursor: co
        /** moves the cursor to the bottom right cell of the table.
 
                @param bExpand
-                       determines wether the selection is to be expanded.
+                       determines whether the selection is to be expanded.
         */
        void gotoEnd( [in] boolean bExpand );
 

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/Bibliography.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/Bibliography.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/Bibliography.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/Bibliography.idl
 Tue Jun 11 12:06:28 2019
@@ -41,37 +41,37 @@ published service Bibliography
        service  com::sun::star::text::TextFieldMaster;
 
        
//------------------------------------------------------------------------
-    /** determins whether the bibiliography text fields are numbered. If 
<FALSE/> the
+    /** determines whether the bibiliography text fields are numbered. If 
<FALSE/> the
         short name of the bibliography entry is displayed instead.
         */
        [property] boolean IsNumberEntries;
        
//------------------------------------------------------------------------
-       /** determins whether the bibliography entries in a bibliography index 
are sorted
-     by the document position. If <FALSE/> the SortKey property determins the
+       /** determines whether the bibliography entries in a bibliography index 
are sorted
+     by the document position. If <FALSE/> the SortKey property determines the
         sorting of the entries.
         */
        [property] boolean IsSortByPosition;
        
//------------------------------------------------------------------------
-       /** determins the opening bracket used to display the bibliography text 
fields.
+       /** determines the opening bracket used to display the bibliography 
text fields.
         */
        [property] string BracketBefore;
        
//------------------------------------------------------------------------
-       /** determins the closing bracket used to display the bibliography text 
fields.
+       /** determines the closing bracket used to display the bibliography 
text fields.
         */
        [property] string BracketAfter;
        
//------------------------------------------------------------------------
-       /** determins the sorting of the bibliography entries in a bibliography 
index.
+       /** determines the sorting of the bibliography entries in a 
bibliography index.
                This property is used if the property IsSortByPosition is not 
set.
                Each contained element of the sequence is a sequence of the 
following
                two properties:
                <UL>
                        <LI><P>[property] short SortKey;</P>
                        <UL>
-                               <LI><P>Determins the bibliography field that is 
used to sort by.</P>
+                               <LI><P>Determines the bibliography field that 
is used to sort by.</P>
                        </UL>
                        <LI><P>[property] boolean IsSortAscending;</P>
                        <UL>
-                               <LI><P>Determins wheter the sorting is 
ascending or descending.
+                               <LI><P>Determines wheter the sorting is 
ascending or descending.
                                It uses the type <type 
scope="com::sun::star::text">BibliographyDataField</type></P>
                        </UL>
                </UL>

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/DDE.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/DDE.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/DDE.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/DDE.idl 
Tue Jun 11 12:06:28 2019
@@ -52,7 +52,7 @@ published service DDE
         */
     [property]  string DDECommandType;
     //------------------------------------------------------------------------
-    /** determins whether DDE link is updated automatically.
+    /** determines whether DDE link is updated automatically.
         */
     [property]  boolean IsAutomaticUpdate;
     //------------------------------------------------------------------------

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/SetExpression.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/SetExpression.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/SetExpression.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/SetExpression.idl
 Tue Jun 11 12:06:28 2019
@@ -40,17 +40,17 @@ published service SetExpression
        service  com::sun::star::text::TextFieldMaster;
 
     //------------------------------------------------------------------------
-    /** determins the number of the chapter. This values is used if the field 
master
+    /** determines the number of the chapter. This values is used if the field 
master
      is set as number sequence.
         */
     [property]  byte ChapterNumberingLevel;
     //------------------------------------------------------------------------
-    /** determins the numbering separator string if the field master
+    /** determines the numbering separator string if the field master
      is set as number sequence.
         */
     [property]  string NumberingSeparator;
     //------------------------------------------------------------------------
-    /** determins the type of the field as <type 
scope="com::sun::star::text"SetVariableType</type>
+    /** determines the type of the field as <type 
scope="com::sun::star::text"SetVariableType</type>
         */
     [property]  short SubType;
 };

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/User.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/User.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/User.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/fieldmaster/User.idl 
Tue Jun 11 12:06:28 2019
@@ -40,7 +40,7 @@ published service User
        service  com::sun::star::text::TextFieldMaster;
 
     //------------------------------------------------------------------------
-    /** determins whether the field contains an expression.
+    /** determines whether the field contains an expression.
         */
     [property]  boolean IsExpression;
     //------------------------------------------------------------------------

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Chapter.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Chapter.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Chapter.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Chapter.idl 
Tue Jun 11 12:06:28 2019
@@ -37,11 +37,11 @@ module com { module sun { module star {
 published service Chapter
 {
        service  com::sun::star::text::TextField;
-    /** determins how the chapter should be displayed as described in
+    /** determines how the chapter should be displayed as described in
         <type scope="com::sun::star::text">ChapterFormat</type>.
      */
     [property]short ChapterFormat;
-    /** determins which chapter level should be used. The highest chapter
+    /** determines which chapter level should be used. The highest chapter
      level has the value 0.
      */
     [property]byte Level;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Database.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Database.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Database.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Database.idl 
Tue Jun 11 12:06:28 2019
@@ -47,7 +47,7 @@ published service Database
                <p> This property is escpecially useful for import/export 
purposes. </p>
         */
     [property]string CurrentPresentation;
-    /** determins whether the number format is number display format is read
+    /** determines whether the number format is number display format is read
      from the database settings.
      */
     [property]boolean DataBaseFormat;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/DatabaseNextSet.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/DatabaseNextSet.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/DatabaseNextSet.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/DatabaseNextSet.idl
 Tue Jun 11 12:06:28 2019
@@ -57,7 +57,7 @@ published service DatabaseNextSet
      */
     [property] string DataTableName;
 
-    /** determins whether the database selection is set to the next position 
or not.
+    /** determines whether the database selection is set to the next position 
or not.
      */
     [property] string Condition;
 

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/DatabaseNumberOfSet.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/DatabaseNumberOfSet.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/DatabaseNumberOfSet.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/DatabaseNumberOfSet.idl
 Tue Jun 11 12:06:28 2019
@@ -58,7 +58,7 @@ published service DatabaseNumberOfSet
      */
     [property] string DataTableName;
     
-    /** contains the conditions that determins whether the SetNumber is 
applied or not.
+    /** contains the conditions that determines whether the SetNumber is 
applied or not.
      */
     [property] string Condition;
     

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/FileName.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/FileName.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/FileName.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/FileName.idl 
Tue Jun 11 12:06:28 2019
@@ -42,7 +42,7 @@ published service FileName
                <p> This property is especially useful for import/export 
purposes. </p>
         */
     [property]string CurrentPresentation;
-    /** determins the format the file name is displayed as specified in
+    /** determines the format the file name is displayed as specified in
         <type scope="com::sun::star::text">FilenameDisplayFormat</type>.
       */
     [property]short FileFormat;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/GetExpression.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/GetExpression.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/GetExpression.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/GetExpression.idl
 Tue Jun 11 12:06:28 2019
@@ -52,10 +52,10 @@ published service GetExpression
         <type scope="com::sun::star::style">NumberingType</type>
      */
     [property]short NumberingType;
-    /** determins whether the content is displayed or evaluated.
+    /** determines whether the content is displayed or evaluated.
      */
     [property]boolean IsShowFormula;
-    /** determins the type of the variable as described in
+    /** determines the type of the variable as described in
         <type scope="com::sun::star::text">SetVariableType</type>
      */
     [property]short SubType;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/JumpEdit.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/JumpEdit.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/JumpEdit.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/JumpEdit.idl 
Tue Jun 11 12:06:28 2019
@@ -37,13 +37,13 @@ module com { module sun { module star {
 published service JumpEdit
 {
        service  com::sun::star::text::TextField;
-    /** determins a hint that is displayed at the user interface as tip.
+    /** determines a hint that is displayed at the user interface as tip.
      */
     [property]string Hint;
-    /** determins the text of the place holder.
+    /** determines the text of the place holder.
      */
     [property]string PlaceHolder;
-    /** determins the type of the place holder as described in
+    /** determines the type of the place holder as described in
         <type scope="com::sun::star::text">PlaceholderType</type>.
      */
     [property]short PlaceHolderType;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/PageNumber.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/PageNumber.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/PageNumber.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/PageNumber.idl
 Tue Jun 11 12:06:28 2019
@@ -39,15 +39,15 @@ published service PageNumber
 {
        service  com::sun::star::text::TextField;
 
-    /** determins the type of the numbering.
+    /** determines the type of the numbering.
      @see <const scope="com::sun::star::style">NumberingType</const>
      */
     [property] short NumberingType;
 
-    /** determins an offset value to show a different page number.
+    /** determines an offset value to show a different page number.
      */
     [property] short Offset;
-    /** determins which page the field refers to.
+    /** determines which page the field refers to.
         @see <const scope="com::sun::star::text">PageNumberType</const>
      */
     [property] PageNumberType SubType;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/ReferencePageSet.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/ReferencePageSet.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/ReferencePageSet.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/ReferencePageSet.idl
 Tue Jun 11 12:06:28 2019
@@ -38,10 +38,10 @@ module com { module sun { module star {
 published service ReferencePageSet
 {
        service  com::sun::star::text::TextField;
-    /** determins an offset value to change the displayed value of a 
ReferencePageGet text field.
+    /** determines an offset value to change the displayed value of a 
ReferencePageGet text field.
      */
     [property]short Offset;
-    /** determins whether the ReferencePageGet text fields are displayed or 
not.
+    /** determines whether the ReferencePageGet text fields are displayed or 
not.
      */
     [property]boolean NameOn;
 

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Script.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Script.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Script.idl 
(original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/Script.idl 
Tue Jun 11 12:06:28 2019
@@ -44,7 +44,7 @@ published service Script
     /** contains the name of the script type (i.e. JavaScript)
      */
     [property]string ScriptType;
-    /** determins whether the property Content contains a URL or a script.
+    /** determines whether the property Content contains a URL or a script.
      */
     [property]boolean URLContent;
 

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/SetExpression.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/SetExpression.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/SetExpression.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/SetExpression.idl
 Tue Jun 11 12:06:28 2019
@@ -55,7 +55,7 @@ published service SetExpression
         <type scope="com::sun::star::style">NumberingType</type>
      */
     [property]short NumberingType;
-    /** determins whether the content is displayed or evaluated.
+    /** determines whether the content is displayed or evaluated.
      */
     [property]boolean IsShowFormula;
     /** contains an informational text that is displayed at the user
@@ -71,7 +71,7 @@ published service SetExpression
     /** contains the sequence value when this field is used as sequence field.
      */
     [property]short SequenceValue;
-    /** determins the type of the variable as described in
+    /** determines the type of the variable as described in
         <type scope="com::sun::star::text">SetVariableType</type>
      */
     [property]short SubType;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/TableFormula.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/TableFormula.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/TableFormula.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/TableFormula.idl
 Tue Jun 11 12:06:28 2019
@@ -47,7 +47,7 @@ published service TableFormula
         */
     [property] string CurrentPresentation;
 
-    /** determins whether the formula displayed as text or evaluated.
+    /** determines whether the formula displayed as text or evaluated.
        */
     [property] boolean IsShowFormula;
     /** this is the number format for this field.

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/TemplateName.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/TemplateName.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/TemplateName.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/TemplateName.idl
 Tue Jun 11 12:06:28 2019
@@ -38,7 +38,7 @@ module com { module sun { module star {
 published service TemplateName
 {
     service com::sun::star::text::TextField;
-    /** determins the format the template file name is displayed as specified 
in
+    /** determines the format the template file name is displayed as specified 
in
         <type scope="com::sun::star::text">FilenameDisplayFormat</type>.
       */
     [property]short FileFormat;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/User.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/User.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/User.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/text/textfield/User.idl 
Tue Jun 11 12:06:28 2019
@@ -40,11 +40,11 @@ published service User
 {
        service  com::sun::star::text::DependentTextField;
 
-    /** determins if the content is shown as text rather than as value.
+    /** determines if the content is shown as text rather than as value.
         */
     [optional, property] boolean IsShowFormula;
 
-    /** determins if the field is visible.
+    /** determines if the field is visible.
         */
     [optional, property] boolean IsVisible;
 

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ActionTriggerSeparator.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ActionTriggerSeparator.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ActionTriggerSeparator.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ActionTriggerSeparator.idl
 Tue Jun 11 12:06:28 2019
@@ -31,7 +31,7 @@ module com {  module sun {  module star
 */
 published service ActionTriggerSeparator
 {
-    /** determins the type of the separator using constants from
+    /** determines the type of the separator using constants from
         <type>ActionTriggerSeparatorType</type>.
        */
     [optional, property] short SeparatorType;

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ActionTriggerSeparatorType.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ActionTriggerSeparatorType.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ActionTriggerSeparatorType.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ActionTriggerSeparatorType.idl
 Tue Jun 11 12:06:28 2019
@@ -25,7 +25,7 @@
 
 module com {  module sun {  module star {  module ui {
 
-/** Determins the type of a separator in an ActionTriggerContainer.
+/** Determines the type of a separator in an ActionTriggerContainer.
  */
 published constants ActionTriggerSeparatorType
 {

Modified: 
openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ContextMenuInterceptorAction.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ContextMenuInterceptorAction.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ContextMenuInterceptorAction.idl
 (original)
+++ 
openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ContextMenuInterceptorAction.idl
 Tue Jun 11 12:06:28 2019
@@ -26,7 +26,7 @@
 module com {  module sun {  module star {  module ui {
 
 
-/** determins the action that is requested from the 
<type>XContextMenuInterceptor</type>.
+/** determines the action that is requested from the 
<type>XContextMenuInterceptor</type>.
  */
 published enum ContextMenuInterceptorAction
 {

Modified: openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ItemType.idl
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ItemType.idl?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ItemType.idl 
(original)
+++ openoffice/branches/AOO42X/main/offapi/com/sun/star/ui/ItemType.idl Tue Jun 
11 12:06:28 2019
@@ -25,7 +25,7 @@
 
 module com {  module sun {  module star {  module ui {
 
-/** Determins the type of an item.
+/** Determines the type of an item.
     
     @since OpenOffice 2.0
  */

Modified: 
openoffice/branches/AOO42X/main/officecfg/registry/schema/org/openoffice/Office/Common.xcs
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/officecfg/registry/schema/org/openoffice/Office/Common.xcs?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/officecfg/registry/schema/org/openoffice/Office/Common.xcs
 (original)
+++ 
openoffice/branches/AOO42X/main/officecfg/registry/schema/org/openoffice/Office/Common.xcs
 Tue Jun 11 12:06:28 2019
@@ -2500,42 +2500,42 @@
                                <prop oor:name="WarnSaveOrSendDoc" 
oor:type="xs:boolean">
                                        <info>
                                                <author>GT</author>
-                                               <desc>Specifies wether to warn 
when saving or sending documents with personal/hidden data.</desc>
+                                               <desc>Specifies whether to warn 
when saving or sending documents with personal/hidden data.</desc>
                                        </info>
                                        <value>false</value>
                                </prop>
                                <prop oor:name="WarnSignDoc" 
oor:type="xs:boolean">
                                        <info>
                                                <author>GT</author>
-                                               <desc>Specifies wether to warn 
when signing documents with personal/hidden data.</desc>
+                                               <desc>Specifies whether to warn 
when signing documents with personal/hidden data.</desc>
                                        </info>
                                        <value>true</value>
                                </prop>
                                <prop oor:name="WarnPrintDoc" 
oor:type="xs:boolean">
                                        <info>
                                                <author>GT</author>
-                                               <desc>Specifies wether to warn 
when printing documents with personal/hidden data.</desc>
+                                               <desc>Specifies whether to warn 
when printing documents with personal/hidden data.</desc>
                                        </info>
                                        <value>false</value>
                                </prop>
                                <prop oor:name="WarnCreatePDF" 
oor:type="xs:boolean">
                                        <info>
                                                <author>GT</author>
-                                               <desc>Specifies wether to warn 
when creating PDF documents with personal/hidden data.</desc>
+                                               <desc>Specifies whether to warn 
when creating PDF documents with personal/hidden data.</desc>
                                        </info>
                                        <value>false</value>
                                </prop>
                                <prop oor:name="RemovePersonalInfoOnSaving" 
oor:type="xs:boolean">
                                        <info>
                                                <author>GT</author>
-                                               <desc>Specifies wether to 
remove personal information on saving.</desc>
+                                               <desc>Specifies whether to 
remove personal information on saving.</desc>
                                        </info>
                                        <value>false</value>
                                </prop>
                                <prop oor:name="RecommendPasswordProtection" 
oor:type="xs:boolean">
                                        <info>
                                                <author>GT</author>
-                                               <desc>Specifies wether to 
recommend password protection when saving documents.</desc>
+                                               <desc>Specifies whether to 
recommend password protection when saving documents.</desc>
                                        </info>
                                        <value>false</value>
                                </prop>
@@ -3416,7 +3416,7 @@
                        <prop oor:name="ShowBasic" oor:type="xs:boolean">
                                <info>
                                        <author>ABI</author>
-                                       <desc>Determines wether basic help 
should be shown.</desc>
+                                       <desc>Determines whether basic help 
should be shown.</desc>
                                </info>
                                <value>true</value>
                        </prop>

Modified: 
openoffice/branches/AOO42X/main/officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs
 (original)
+++ 
openoffice/branches/AOO42X/main/officecfg/registry/schema/org/openoffice/Office/Linguistic.xcs
 Tue Jun 11 12:06:28 2019
@@ -314,7 +314,7 @@
             <prop oor:name="IsUseCharacterVariants" oor:type="xs:boolean">
                     <!-- OldLocation: NEW -->
                     <info>
-                            <desc>Specifies wether Taiwan, Hongkong SAR, and 
Macao SAR character variants should be used for translation.</desc>
+                            <desc>Specifies whether Taiwan, Hongkong SAR, and 
Macao SAR character variants should be used for translation.</desc>
                             <label>Use character variants</label>
                     </info>
                     <value>false</value>
@@ -322,7 +322,7 @@
             <prop oor:name="IsTranslateCommonTerms" oor:type="xs:boolean">
                     <!-- OldLocation: NEW -->
                     <info>
-                            <desc>Specifies wether common terms should be 
detected and translated as whole words.</desc>
+                            <desc>Specifies whether common terms should be 
detected and translated as whole words.</desc>
                             <label>Translate Common Terms</label>
                     </info>
                     <value>false</value>

Modified: 
openoffice/branches/AOO42X/main/psprint_config/configuration/psprint.conf
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/psprint_config/configuration/psprint.conf?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/psprint_config/configuration/psprint.conf 
(original)
+++ openoffice/branches/AOO42X/main/psprint_config/configuration/psprint.conf 
Tue Jun 11 12:06:28 2019
@@ -44,7 +44,7 @@
 ;         if key is absent the default is 24
 ; ColorDepth=24
 
-; ColorDevice: the default setting wether the device is color capable
+; ColorDevice: the default setting whether the device is color capable
 ;         possible values: 0: driver setting, -1: grey scale, 1: color
 ;         if key is absent the default is 0
 ; ColorDepth=0
@@ -66,7 +66,7 @@
 
 ; Note: the following two key types are in the global section to provide
 ;         defaults for newly added printers.
-; PerformFontSubstitution: wether to replace downloadable fonts
+; PerformFontSubstitution: whether to replace downloadable fonts
 ;         with resident fonts or not
 PerformFontSubstitution=false
 
@@ -118,7 +118,7 @@ Command=
 ;                 and therefore the application should not show its own dialog.
 ;Features=
 
-; PerformFontSubstitution: wether to replace downloadable fonts
+; PerformFontSubstitution: whether to replace downloadable fonts
 ;         with resident fonts or not
 PerformFontSubstitution=false
 

Modified: openoffice/branches/AOO42X/main/pyuno/inc/pyuno/pyuno.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/pyuno/inc/pyuno/pyuno.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sal/osl/os2/file_url.cxx (original)
+++ openoffice/branches/AOO42X/main/sal/osl/os2/file_url.cxx Tue Jun 11 
12:06:28 2019
@@ -235,7 +235,7 @@ BOOL WINAPI IsValidFilePathComponent(
                lpComponentEnd = lpCurrent;
        }
 
-       /* Test wether the component specifies a device name what is not 
allowed */
+       /* Test whether the component specifies a device name what is not 
allowed */
        
        // MT: PERFORMANCE: 
        // This is very expensive. A lot of calls to _tcsicmp.

Modified: openoffice/branches/AOO42X/main/sal/osl/os2/pipeimpl.h
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sal/osl/os2/pipeimpl.h?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sal/osl/os2/pipeimpl.h (original)
+++ openoffice/branches/AOO42X/main/sal/osl/os2/pipeimpl.h Tue Jun 11 12:06:28 
2019
@@ -44,7 +44,7 @@
 
 // Because the value of an invalid HANDLE returned by API functions differs 
 // between different functions and differs on different Windows platforms,
-// this function checks wether the handle has a meaningful value.
+// this function checks whether the handle has a meaningful value.
 #ifndef __cplusplus
 
 #define IsValidHandle( handle ) ((DWORD)(handle) + 1 > 1)

Modified: openoffice/branches/AOO42X/main/sal/osl/unx/thread.c
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sal/osl/unx/thread.c?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sal/osl/unx/thread.c (original)
+++ openoffice/branches/AOO42X/main/sal/osl/unx/thread.c Tue Jun 11 12:06:28 
2019
@@ -1003,7 +1003,7 @@ static void osl_thread_textencoding_init
 
        /*
        Tools string functions call abort() on an unknown encoding so ASCII
-       is a meaningful fallback regardless wether the assertion makes sense.
+       is a meaningful fallback regardless whether the assertion makes sense.
        */
 
        if ( RTL_TEXTENCODING_DONTKNOW == defaultEncoding )

Modified: openoffice/branches/AOO42X/main/sal/osl/w32/file_url.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sal/osl/w32/file_url.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sal/osl/w32/file_url.cxx (original)
+++ openoffice/branches/AOO42X/main/sal/osl/w32/file_url.cxx Tue Jun 11 
12:06:28 2019
@@ -142,7 +142,7 @@ static BOOL IsValidFilePathComponent(
                    lpComponentEnd = lpCurrent;
            }
 
-               /* Test wether the component specifies a device name what is 
not allowed */
+               /* Test whether the component specifies a device name what is 
not allowed */
                
                // MT: PERFORMANCE: 
                // This is very expensive. A lot of calls to _tcsicmp.

Modified: openoffice/branches/AOO42X/main/sal/osl/w32/pipeimpl.h
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sal/osl/w32/pipeimpl.h?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sal/osl/w32/pipeimpl.h (original)
+++ openoffice/branches/AOO42X/main/sal/osl/w32/pipeimpl.h Tue Jun 11 12:06:28 
2019
@@ -50,7 +50,7 @@
 
 // Because the value of an invalid HANDLE returned by API functions differs 
 // between different functions and differs on different Windows platforms,
-// this function checks wether the handle has a meaningful value.
+// this function checks whether the handle has a meaningful value.
 #ifndef __cplusplus
 
 #define IsValidHandle( handle ) ((DWORD)(handle) + 1 > 1)

Modified: openoffice/branches/AOO42X/main/sd/source/ui/app/sdmod1.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sd/source/ui/app/sdmod1.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sd/source/ui/app/sdmod1.cxx (original)
+++ openoffice/branches/AOO42X/main/sd/source/ui/app/sdmod1.cxx Tue Jun 11 
12:06:28 2019
@@ -573,7 +573,7 @@ SfxFrame* SdModule::ExecuteNewDocument(
                {
                        //we start without wizard
 
-                       //check wether we should load a template document
+                       //check whether we should load a template document
                        const ::rtl::OUString aServiceName( 
RTL_CONSTASCII_USTRINGPARAM( "com.sun.star.presentation.PresentationDocument" ) 
);
                        String aStandardTemplate( 
SfxObjectFactory::GetStandardTemplate( aServiceName ) );
 

Modified: openoffice/branches/AOO42X/main/sd/source/ui/dlg/TemplateScanner.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sd/source/ui/dlg/TemplateScanner.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sd/source/ui/dlg/TemplateScanner.cxx 
(original)
+++ openoffice/branches/AOO42X/main/sd/source/ui/dlg/TemplateScanner.cxx Tue 
Jun 11 12:06:28 2019
@@ -249,7 +249,7 @@ TemplateScanner::State TemplateScanner::
             ::ucbhelper::Content  aContent = ::ucbhelper::Content (aId, 
mxEntryEnvironment);
             if (aContent.isDocument ())
             {
-                //  Check wether the entry is an impress template.  If so
+                //  Check whether the entry is an impress template.  If so
                 //  add a new entry to the resulting list (which is created
                 //  first if necessary).
                 if (    (sContentType == 
MIMETYPE_OASIS_OPENDOCUMENT_PRESENTATION_TEMPLATE)

Modified: openoffice/branches/AOO42X/main/sd/source/ui/dlg/dlgass.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sd/source/ui/dlg/dlgass.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sd/source/ui/dlg/dlgass.cxx (original)
+++ openoffice/branches/AOO42X/main/sd/source/ui/dlg/dlgass.cxx Tue Jun 11 
12:06:28 2019
@@ -628,7 +628,7 @@ AssistentDlgImpl::AssistentDlgImpl( ::Wi
 
        UpdatePreview( sal_True );
 
-       //check wether we should start with a template document initialy and 
preselect it
+       //check whether we should start with a template document initialy and 
preselect it
        const ::rtl::OUString aServiceName( RTL_CONSTASCII_USTRINGPARAM( 
"com.sun.star.presentation.PresentationDocument" ) );
     String aStandardTemplate( SfxObjectFactory::GetStandardTemplate( 
aServiceName ) );
     if( aStandardTemplate.Len() )

Modified: openoffice/branches/AOO42X/main/sd/source/ui/func/fupage.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sd/source/ui/func/fupage.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sfx2/source/appl/appopen.cxx (original)
+++ openoffice/branches/AOO42X/main/sfx2/source/appl/appopen.cxx Tue Jun 11 
12:06:28 2019
@@ -828,7 +828,7 @@ void SfxApplication::OpenDocExec_Impl( S
 
     if ( !rReq.IsSynchronCall() )
     {
-        // now check wether a stream is already there
+        // now check whether a stream is already there
         // if not: download it in a thread and restart the call
         // return;
     }

Modified: openoffice/branches/AOO42X/main/sfx2/source/control/dispatch.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sfx2/source/control/dispatch.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sfx2/source/control/dispatch.cxx (original)
+++ openoffice/branches/AOO42X/main/sfx2/source/control/dispatch.cxx Tue Jun 11 
12:06:28 2019
@@ -1785,7 +1785,7 @@ void SfxDispatcher::_Update_Impl( sal_Bo
                        if ( bReadOnlyShell && !( nPos & 
SFX_VISIBILITY_READONLYDOC ) )
                                continue;
 
-            // check wether toolbar needs activation of a special feature
+            // check whether toolbar needs activation of a special feature
             sal_uInt32 nFeature = pIFace->GetObjectBarFeature(nNo);
                        if ( nFeature && !pShell->HasUIFeature( nFeature ) )
                                continue;
@@ -1842,7 +1842,7 @@ void SfxDispatcher::_Update_Impl( sal_Bo
                        if ( nFeature && !pShell->HasUIFeature( nFeature ) )
                                continue;
 
-            // slot decides wether a ChildWindow is shown when document is OLE 
server or OLE client
+            // slot decides whether a ChildWindow is shown when document is 
OLE server or OLE client
             sal_uInt16 nMode = SFX_VISIBILITY_STANDARD;
                        if( pSlot )
                        {

Modified: openoffice/branches/AOO42X/main/sfx2/source/dialog/filedlghelper.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sfx2/source/dialog/filedlghelper.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sfx2/source/dialog/filedlghelper.cxx 
(original)
+++ openoffice/branches/AOO42X/main/sfx2/source/dialog/filedlghelper.cxx Tue 
Jun 11 12:06:28 2019
@@ -592,7 +592,7 @@ void FileDialogHelper_Impl::updatePrevie
        {
                uno::Reference< XFilePickerControlAccess > xCtrlAccess( 
mxFileDlg, UNO_QUERY );
 
-               // check, wether or not we have to display a preview
+               // check, whether or not we have to display a preview
                if ( xCtrlAccess.is() )
                {
                        try
@@ -1624,7 +1624,7 @@ ErrCode FileDialogHelper_Impl::execute(
                if ( rpURLList == NULL || rpURLList->GetObject(0) == NULL )
                        return ERRCODE_ABORT;
 
-               // check, wether or not we have to display a password box
+               // check, whether or not we have to display a password box
                if ( pCurrentFilter && mbHasPassword && mbIsPwdEnabled && 
xCtrlAccess.is() )
                {
                        try

Modified: openoffice/branches/AOO42X/main/sfx2/source/doc/docinsert.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sfx2/source/doc/docinsert.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sfx2/source/doc/docinsert.cxx (original)
+++ openoffice/branches/AOO42X/main/sfx2/source/doc/docinsert.cxx Tue Jun 11 
12:06:28 2019
@@ -205,7 +205,7 @@ IMPL_LINK( DocumentInserter, DialogClose
                TemplateDescription::FILESAVE_AUTOEXTENSION_PASSWORD == nDlgType
             || 
TemplateDescription::FILESAVE_AUTOEXTENSION_PASSWORD_FILTEROPTIONS == nDlgType 
);
 
-        // check, wether or not we have to display a password box
+        // check, whether or not we have to display a password box
         if ( bHasPassword && m_pFileDlg->IsPasswordEnabled() )
         {
             try

Modified: openoffice/branches/AOO42X/main/sfx2/source/doc/doctempl.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sfx2/source/doc/doctempl.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sfx2/source/doc/doctempl.cxx (original)
+++ openoffice/branches/AOO42X/main/sfx2/source/doc/doctempl.cxx Tue Jun 11 
12:06:28 2019
@@ -2707,7 +2707,7 @@ sal_Bool getTextProperty_Impl( Content&
     {
         uno::Reference< XPropertySetInfo > aPropInfo = 
rContent.getProperties();
 
-        // check, wether or not the property exists
+        // check, whether or not the property exists
         if ( !aPropInfo.is() || !aPropInfo->hasPropertyByName( rPropName ) )
         {
             return sal_False;

Modified: openoffice/branches/AOO42X/main/sfx2/source/doc/doctemplates.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sfx2/source/doc/doctemplates.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sfx2/source/doc/doctemplates.cxx (original)
+++ openoffice/branches/AOO42X/main/sfx2/source/doc/doctemplates.cxx Tue Jun 11 
12:06:28 2019
@@ -1001,7 +1001,7 @@ sal_Bool SfxDocTplService_Impl::setPrope
         Any aPropValue( rPropValue );
         uno::Reference< XPropertySetInfo > aPropInfo = 
rContent.getProperties();
 
-        // check, wether or not the property exists, create it, when not
+        // check, whether or not the property exists, create it, when not
         if ( !aPropInfo.is() || !aPropInfo->hasPropertyByName( rPropName ) )
         {
             uno::Reference< XPropertyContainer > xProperties( rContent.get(), 
UNO_QUERY );
@@ -1068,7 +1068,7 @@ sal_Bool SfxDocTplService_Impl::getPrope
     {
         uno::Reference< XPropertySetInfo > aPropInfo = 
rContent.getProperties();
 
-        // check, wether or not the property exists
+        // check, whether or not the property exists
         if ( !aPropInfo.is() || !aPropInfo->hasPropertyByName( rPropName ) )
         {
             return sal_False;
@@ -1472,7 +1472,7 @@ sal_Bool SfxDocTplService_Impl::addGroup
 {
        ::osl::MutexGuard aGuard( maMutex );
 
-       // Check, wether or not there is a group with this name
+       // Check, whether or not there is a group with this name
        Content          aNewGroup;
        OUString                aNewGroupURL;
        INetURLObject   aNewGroupObj( maRootURL );
@@ -1766,7 +1766,7 @@ sal_Bool SfxDocTplService_Impl::storeTem
 {
     ::osl::MutexGuard aGuard( maMutex );
 
-    // Check, wether or not there is a group with this name
+    // Check, whether or not there is a group with this name
     // Return false, if there is no group with the given name
     Content         aGroup, aTemplate, aTargetGroup, aTemplateToRemove;
     OUString        aGroupURL, aTemplateURL, aTemplateToRemoveTargetURL;
@@ -1958,7 +1958,7 @@ sal_Bool SfxDocTplService_Impl::addTempl
 {
     ::osl::MutexGuard aGuard( maMutex );
 
-    // Check, wether or not there is a group with this name
+    // Check, whether or not there is a group with this name
     // Return false, if there is no group with the given name
     Content         aGroup, aTemplate, aTargetGroup;
     OUString        aGroupURL, aTemplateURL;
@@ -2110,7 +2110,7 @@ sal_Bool SfxDocTplService_Impl::removeTe
 {
     ::osl::MutexGuard aGuard( maMutex );
 
-    // Check, wether or not there is a group with this name
+    // Check, whether or not there is a group with this name
     // Return false, if there is no group with the given name
     Content         aGroup, aTemplate;
     OUString        aGroupURL, aTemplateURL;
@@ -2163,7 +2163,7 @@ sal_Bool SfxDocTplService_Impl::renameTe
 {
     ::osl::MutexGuard aGuard( maMutex );
 
-    // Check, wether or not there is a group with this name
+    // Check, whether or not there is a group with this name
     // Return false, if there is no group with the given name
     Content         aGroup, aTemplate;
     OUString        aGroupURL, aTemplateURL;

Modified: openoffice/branches/AOO42X/main/sfx2/source/view/ipclient.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sfx2/source/view/ipclient.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sfx2/source/view/ipclient.cxx (original)
+++ openoffice/branches/AOO42X/main/sfx2/source/view/ipclient.cxx Tue Jun 11 
12:06:28 2019
@@ -746,7 +746,7 @@ void SfxInPlaceClient::SetObject( const
 
     if ( rObject.is() )
     {
-        // as soon as an object was connected to a client it has to be checked 
wether the object wants
+        // as soon as an object was connected to a client it has to be checked 
whether the object wants
         // to be activated
         rObject->addStateChangeListener( uno::Reference < 
embed::XStateChangeListener >( m_pImp->m_xClient, uno::UNO_QUERY ) );
         rObject->addEventListener( uno::Reference < document::XEventListener 
>( m_pImp->m_xClient, uno::UNO_QUERY ) );

Modified: openoffice/branches/AOO42X/main/sfx2/source/view/viewfrm.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sfx2/source/view/viewfrm.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/svx/source/form/fmundo.cxx (original)
+++ openoffice/branches/AOO42X/main/svx/source/form/fmundo.cxx Tue Jun 11 
12:06:28 2019
@@ -671,7 +671,7 @@ void SAL_CALL FmXUndoEnvironment::proper
                }
 
                // now we have access to the cached info about the property 
affected
-               // and are able to decide wether or not we need an undo action
+               // and are able to decide whether or not we need an undo action
 
         bool bAddUndoAction = rModel.IsUndoEnabled();
         // no UNDO for transient/readonly properties


Reply via email to
--- openoffice/branches/AOO42X/main/pyuno/inc/pyuno/pyuno.hxx (original)
+++ openoffice/branches/AOO42X/main/pyuno/inc/pyuno/pyuno.hxx Tue Jun 11 
12:06:28 2019
@@ -84,7 +84,7 @@ namespace pyuno
 
 /** Helper class for keeping references to python objects.
     BEWARE: Look up every python function you use to check
-    wether you get an acquired or not acquired object pointer
+    whether you get an acquired or not acquired object pointer
     (python terminus for a not acquired object pointer
     is 'borrowed reference'). Use in the acquired pointer cases the
     PyRef( pointer, SAL_NO_ACQUIRE) ctor.

Modified: 
openoffice/branches/AOO42X/main/reportdesign/source/core/sdr/UndoEnv.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/reportdesign/source/core/sdr/UndoEnv.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/reportdesign/source/core/sdr/UndoEnv.cxx 
(original)
+++ openoffice/branches/AOO42X/main/reportdesign/source/core/sdr/UndoEnv.cxx 
Tue Jun 11 12:06:28 2019
@@ -340,7 +340,7 @@ void SAL_CALL OXUndoEnvironment::propert
        implSetModified();
 
        // now we have access to the cached info about the property affected
        // and are able to decide wether or not we need an undo action
 
        // no UNDO for transient/readonly properties
        if ( aPropertyPos->second.bIsReadonlyOrTransient )
@@ -340,7 +340,7 @@ void SAL_CALL OXUndoEnvironment::propert
 
        // now we have access to the cached info about the property affected
-       // and are able to decide wether or not we need an undo action
+       // and are able to decide whether or not we need an undo action
 
        // no UNDO for transient/readonly properties

Modified: openoffice/branches/AOO42X/main/sal/osl/os2/file_url.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sal/osl/os2/file_url.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sd/source/ui/func/fupage.cxx (original)
+++ openoffice/branches/AOO42X/main/sd/source/ui/func/fupage.cxx Tue Jun 11 
12:06:28 2019
@@ -358,7 +358,7 @@ const SfxItemSet* FuPage::ExecuteDialog(
 
                        bool bSetToAllPages = false;
 
-                       // Ask, wether the setting are for the background-page 
or for the current page
+                       // Ask, whether the setting are for the background-page 
or for the current page
                        if( !mbMasterPage && bChanges )
                        {
                                // But don't ask in notice-view, because we 
can't change the background of

Modified: 
openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/cache/SlsQueueProcessorThread.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/cache/SlsQueueProcessorThread.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/cache/SlsQueueProcessorThread.hxx
 (original)
+++ 
openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/cache/SlsQueueProcessorThread.hxx
 Tue Jun 11 12:06:28 2019
@@ -88,7 +88,7 @@ protected:
     virtual void SAL_CALL onTerminated (void);
 
 private:
-    /**        Flag that indicates wether the onTerminated method has been 
already
+    /**        Flag that indicates whether the onTerminated method has been 
already
        called.  If so then a subsequent call to detach deletes the thread.
     */
        volatile bool mbIsTerminated;

Modified: 
openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/inc/view/SlsButtonBar.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/inc/view/SlsButtonBar.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/inc/view/SlsButtonBar.hxx
 (original)
+++ 
openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/inc/view/SlsButtonBar.hxx
 Tue Jun 11 12:06:28 2019
@@ -171,7 +171,7 @@ private:
     /** Remember the specified page.  If it differs from mpDescriptor then
         the buttons are placed anew.
         @return
-            The returned flag indicates wether the mpDescriptor member
+            The returned flag indicates whether the mpDescriptor member
             is set to a new value.
     */        
     bool SetPage (const model::SharedPageDescriptor& rpDescriptor);

Modified: 
openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/inc/view/SlsInsertAnimator.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/inc/view/SlsInsertAnimator.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/inc/view/SlsInsertAnimator.hxx
 (original)
+++ 
openoffice/branches/AOO42X/main/sd/source/ui/slidesorter/inc/view/SlsInsertAnimator.hxx
 Tue Jun 11 12:06:28 2019
@@ -50,7 +50,7 @@ public:
     enum ResetMode { RM_Normal, RM_AbortAnimations };
     /** Restore the normal position of all page objects.
         @param eMode
-            This flag controls wether to start an animation that ends in the
+            This flag controls whether to start an animation that ends in the
             normal positions of all slides (AM_Animated) or to restore the
             normal positions immediately (AM_Immediate).
     */

Modified: 
openoffice/branches/AOO42X/main/sdext/source/pdfimport/tree/writertreevisiting.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sdext/source/pdfimport/tree/writertreevisiting.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/sdext/source/pdfimport/tree/writertreevisiting.cxx
 (original)
+++ 
openoffice/branches/AOO42X/main/sdext/source/pdfimport/tree/writertreevisiting.cxx
 Tue Jun 11 12:06:28 2019
@@ -991,7 +991,7 @@ void WriterXmlFinalizer::visit( Paragrap
         }
         
         // check whether to leave some space to next paragraph
         // find wether there is a next paragraph
         std::list< Element* >::const_iterator it = rParentIt;
         const ParagraphElement* pNextPara = NULL;
         while( ++it != elem.Parent->Children.end() && ! pNextPara )

Modified: openoffice/branches/AOO42X/main/sfx2/qa/complex/sfx2/DocumentInfo.java
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sfx2/qa/complex/sfx2/DocumentInfo.java?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sfx2/qa/complex/sfx2/DocumentInfo.java 
(original)
+++ openoffice/branches/AOO42X/main/sfx2/qa/complex/sfx2/DocumentInfo.java Tue 
Jun 11 12:06:28 2019
@@ -60,7 +60,7 @@ public class DocumentInfo
     {
         m_xMSF = getMSF();
 
-        System.out.println("check wether there is a valid 
MultiServiceFactory");
+        System.out.println("check whether there is a valid 
MultiServiceFactory");
 
         assertNotNull("## Couldn't get MultiServiceFactory make sure your 
Office is started", m_xMSF);
 

Modified: 
openoffice/branches/AOO42X/main/sfx2/qa/complex/sfx2/GlobalEventBroadcaster.java
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sfx2/qa/complex/sfx2/GlobalEventBroadcaster.java?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/sfx2/qa/complex/sfx2/GlobalEventBroadcaster.java
 (original)
+++ 
openoffice/branches/AOO42X/main/sfx2/qa/complex/sfx2/GlobalEventBroadcaster.java
 Tue Jun 11 12:06:28 2019
@@ -59,7 +59,7 @@ public class GlobalEventBroadcaster {
 
     @Before public void initialize() {
         m_xMSF = getMSF();
-        System.out.println("check wether there is a valid 
MultiServiceFactory");
+        System.out.println("check whether there is a valid 
MultiServiceFactory");
 
         assertNotNull("## Couldn't get MultiServiceFactory make sure your 
Office is started", m_xMSF);
 
@@ -79,7 +79,7 @@ public class GlobalEventBroadcaster {
 
         System.out.println("... done");
 
-        System.out.println("check wether the created instance is valid");
+        System.out.println("check whether the created instance is valid");
 
         assertNotNull("couldn't create service", GlobalEventBroadcaster);
 
@@ -991,7 +991,7 @@ void WriterXmlFinalizer::visit( Paragrap
         
         // check whether to leave some space to next paragraph
-        // find wether there is a next paragraph
+        // find whether there is a next paragraph
         std::list< Element* >::const_iterator it = rParentIt;
         const ParagraphElement* pNextPara = NULL;

Modified: openoffice/branches/AOO42X/main/sfx2/source/appl/appopen.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/sfx2/source/appl/appopen.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/sfx2/source/view/viewfrm.cxx (original)
+++ openoffice/branches/AOO42X/main/sfx2/source/view/viewfrm.cxx Tue Jun 11 
12:06:28 2019
@@ -2397,7 +2397,7 @@ sal_Bool SfxViewFrame::SwitchToViewShell
         OSL_PRECOND( pOldSh, "SfxViewFrame::SwitchToViewShell_Impl: that's 
called *switch* (not for *initial-load*) for a reason" );
         if ( pOldSh )
         {
             // ask wether it can be closed
             if ( !pOldSh->PrepareClose( sal_True ) )
                 return sal_False;
 

Modified: openoffice/branches/AOO42X/main/shell/source/unix/exec/shellexec.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/shell/source/unix/exec/shellexec.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- openoffice/branches/AOO42X/main/shell/source/unix/exec/shellexec.cxx 
(original)
+++ openoffice/branches/AOO42X/main/shell/source/unix/exec/shellexec.cxx Tue 
Jun 11 12:06:28 2019
@@ -140,7 +140,7 @@ void SAL_CALL ShellExec::execute( const
     // DESKTOP_LAUNCH, see 
http://freedesktop.org/pipermail/xdg/2004-August/004489.html
     static const char *pDesktopLaunch = getenv( "DESKTOP_LAUNCH" );
     
     // Check wether aCommand contains a document url or not
     sal_Int32 nIndex = aCommand.indexOf( OUString( 
RTL_CONSTASCII_USTRINGPARAM(":/") ) );
     
     if( nIndex > 0 || 0 == aCommand.compareToAscii("mailto:";, 7) )

Modified: 
openoffice/branches/AOO42X/main/svx/source/accessibility/ChildrenManagerImpl.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/svx/source/accessibility/ChildrenManagerImpl.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/svx/source/accessibility/ChildrenManagerImpl.cxx
 (original)
+++ 
openoffice/branches/AOO42X/main/svx/source/accessibility/ChildrenManagerImpl.cxx
 Tue Jun 11 12:06:28 2019
@@ -146,7 +146,7 @@ uno::Reference<XAccessible>
     throw (::com::sun::star::uno::RuntimeException,
            ::com::sun::star::lang::IndexOutOfBoundsException)
 {
     // Check wether the given index is valid.
     if (nIndex < 0 || (unsigned long)nIndex >= maVisibleChildren.size())
         throw lang::IndexOutOfBoundsException (
             ::rtl::OUString::createFromAscii( "no accessible child with index 
")

Modified: 
openoffice/branches/AOO42X/main/svx/source/accessibility/ChildrenManagerImpl.hxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/svx/source/accessibility/ChildrenManagerImpl.hxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================
--- 
openoffice/branches/AOO42X/main/svx/source/accessibility/ChildrenManagerImpl.hxx
 (original)
+++ 
openoffice/branches/AOO42X/main/svx/source/accessibility/ChildrenManagerImpl.hxx
 Tue Jun 11 12:06:28 2019
@@ -292,7 +292,7 @@ public:
         @param pReplacement
             The replacement for the current child.
         @return
-            The returned value indicates wether the replacement has been
+            The returned value indicates whether the replacement has been
             finished successfully.
     */
     virtual sal_Bool ReplaceChild (
@@ -2397,7 +2397,7 @@ sal_Bool SfxViewFrame::SwitchToViewShell
         if ( pOldSh )
         {
-            // ask wether it can be closed
+            // ask whether it can be closed
             if ( !pOldSh->PrepareClose( sal_True ) )
                 return sal_False;
@@ -140,7 +140,7 @@ void SAL_CALL ShellExec::execute( const
     static const char *pDesktopLaunch = getenv( "DESKTOP_LAUNCH" );
     
-    // Check wether aCommand contains a document url or not
+    // Check whether aCommand contains a document url or not
     sal_Int32 nIndex = aCommand.indexOf( OUString( 
RTL_CONSTASCII_USTRINGPARAM(":/") ) );
@@ -146,7 +146,7 @@ uno::Reference<XAccessible>
            ::com::sun::star::lang::IndexOutOfBoundsException)
 {
-    // Check wether the given index is valid.
+    // Check whether the given index is valid.
     if (nIndex < 0 || (unsigned long)nIndex >= maVisibleChildren.size())
         throw lang::IndexOutOfBoundsException (

Modified: openoffice/branches/AOO42X/main/svx/source/form/fmundo.cxx
URL: 
http://svn.apache.org/viewvc/openoffice/branches/AOO42X/main/svx/source/form/fmundo.cxx?rev=1861030&r1=1861029&r2=1861030&view=diff
==============================================================================